import React, { useState } from "react";
import PropTypes from "prop-types";
import styled,{ css } from "styled-components";
import { DndProvider } from "react-dnd";
import HTML5Backend from "react-dnd-html5-backend";
import { HorizontalDay } from "./HorizontalDay";
import { DayBlock } from "./DayBlock";
import moment from "moment";

export const CalendarContext = React.createContext(null);

// Create a <Title> react component that renders an <h1> which is
// centered, palevioletred and sized at 1.5em
const Frame = styled.div`
  box-sizing: border-box;
  width: 100%;
  overflow-y: auto;
  display: flex;
  justify-content: space-evenly;
`;

const Time = styled.ul`
    width: 100%;
    margin: 0;
    padding: 0;
    font-size: 12px;
    background: #b1b1b1;
    li{
        display: inline-block;
        list-style: none;
    }
    ${props => css`
        margin-left: ${props.yAxisWidth}px;
        width: ${props.width}px;
    `}
`;

const getLayout = {
  horizontal: styled(Frame)`
    flex-direction: row;
  `,
  vertical: styled(Frame)`
    flex-direction: column;
  `
};

const generateAxis = events => {
  let axis = [];
  if(typeof(events) !== "object") throw new Error('The events property must be an object');
  for (let key in events) {
    axis.push({
      label: key,
      events: events[key].map((e, i) => {
        e.index = key + i;
        e.duration = moment.duration(e.end.diff(e.start)).asMinutes();
        return e;
      })
    });
  }

  return axis;
};

const Calendar = ({ daysToShow, events, onChange, ...rest }) => {
    const Layout = getLayout['horizontal'];
    return (
        <Layout>
            Hello
        </Layout>
    );
};

Calendar.propTypes = {
  timeDirection: PropTypes.string,
  dayDirection: PropTypes.string,
  blockPixelSize: PropTypes.number,
  onChange: PropTypes.func,
  daysToShow: PropTypes.array,
  viewMode: PropTypes.string,
  activeDate: PropTypes.object,
  events: PropTypes.oneOfType([PropTypes.array, PropTypes.object]),
  timeBlockMinutes: PropTypes.number,
  dayWidth: PropTypes.string,
  yAxisWidth: PropTypes.number,
  showFrom: PropTypes.number,
  showUntil: PropTypes.number,
  blockLabel: PropTypes.oneOfType([
    PropTypes.func,
    PropTypes.node
  ]),
  dayLabel: PropTypes.oneOfType([
    PropTypes.func,
    PropTypes.node
  ]),
};

Calendar.defaultProps = {
  timeDirection: "horizontal",
  dayDirection: "vertical",
  onChange: null,
  viewMode: "day",
  dayWidth: "100%",
  activeDate: null,
  blockPixelSize: 30,
  events: [],
  daysToShow: [],
  timeBlockMinutes: 30,
  yAxisWidth: 40,
  dayLabel: null,
  blockLabel: null
};

export default Calendar;